==> gpss-1.00-src.zip: jp/wda/gpss/util/SocketProcessorFinder.java <==
package jp.wda.gpss.util;

/**
 * NCAg\Pbg NX
 *
 * @version	1.00006	2003/05/29
 * @since		1.00003	2003/05/01
 * @author	amoi
 */
public class SocketProcessorFinder extends Finder {
	// RXgN^ ///////////////////////////////////////////////////////////////////
	//                                                                    Constructors //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 *	ftHg̐ݒpăIuWFNg\z܂B<BR>
	 */
	public SocketProcessorFinder(){ super(); }

	// I[@[Ch /////////////////////////////////////////////////////////////////
	//                                                               Over Ride Methods //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 * FinderNXɕKvȃ\bhB<BR>
	 * SocketProcessorFinderNXł͓ɉsȂ܂B<BR>
	 * 
	 * @param elem getlist / get\bhŏ𖞂ƊmFꂽIuWFNg
	 * @return getlist / get\bhŎۂɎgpl
	 * @see jp.wda.gpss.util.Finder#getReturnValue(Object)
	 */
	public Object getReturnValue(Object elem){
		return elem;
	}

	/* ***********************************************************************>> */;
	/**
	 * setNextCondition\bhɕKvȃ\bhB<BR>
	 * VSocketProcessorFinderIuWFNg𐶐܂B<BR>
	 * 
	 * @see jp.wda.gpss.util.Finder#createNewFinder()
	 * @see jp.wda.gpss.util.Finder#setNextCondition(Finder, Condition)
	 */
	protected Finder createNewFinder(){ return new SocketProcessorFinder(); }

	/* ***********************************************************************>> */;
	/**
	 * setNextCondition\bhɕKvȃ\bhB<BR>
	 * ̍ӒlƉEӒlw肵āAVFinderElement̃IuWFNgɒǉ܂B<BR>
	 * Ӓl̓2"p."̏ꍇ́Ap[^lpIuWFNgA<BR>
	 * "a."̏ꍇ̓NCAgŗLlpIuWFNgA<BR>
	 * ̏C傪tĂȂꍇ́A[U[pIuWFNgA<BR>
	 * ̃IuWFNgɒǉ܂B<BR>
	 * 
	 * @see jp.wda.gpss.util.Finder#setNextFinder(boolean, boolean, String, String)
	 * @see jp.wda.gpss.util.Finder#setNextCondition(Finder, Condition)
	 */
	protected void setNextFinder(boolean con, boolean not, String column, String value){
		if(column == null || column.length() < 3){ return; }
//		if(value == null  || value.length() == 0){ return; }
		
		if(column.charAt(1) == '.'){
			if(column.charAt(0) == 'p'){
				addFinder(con, new SocketProcessorFinderByParameter(not, column.substring(2), value));
			}else if(column.charAt(0) == 'a'){
				addFinder(con, new SocketProcessorFinderByAttribute(not, column.substring(2), value));
			}
		}else if(column.equalsIgnoreCase("username")){
			addFinder(con, new SocketProcessorFinderByUsername(not, value));
		}
	}

	// NX\bh ///////////////////////////////////////////////////////////////////
	//                                                                   Class Methods //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 * w肵āAVIuWFNgpIuWFNg쐬܂B<BR>
	 * v́A"=="Aے"!="gpĂB<BR>
	 * ̐ڑɂ́AANDڑ̏ꍇ'&'AORڑ̏ꍇ́A'|'gpł܂B<BR>
	 * ܂A"()"gpď̃O[vo܂B<BR>
	 * <BR>
	 * ̍Ӓlɂ́A[U[͏p[^AŗLwł܂B<BR>
	 * [U[ꍇ́AӒl"username"ƂȂ܂B<BR>
	 * p[^猟ꍇ́Ap[^̓"p."tĂB<BR>
	 * ŗL猟ꍇ́AŗL̓"a."tĂB<BR>
	 * j<BR>
	 * (p.room != osyaberi & (username == amoi | username == kon)) & a.sleep != sleep<BR>
	 * 
	 * @param condition 
	 * @deprecated
	 */
	public static SocketProcessorFinder create(String condition){
		SocketProcessorFinder ret = new SocketProcessorFinder();
		ret.setCondition(condition);
		return ret;
	}

	/* ***********************************************************************>> */;
	/**
	 * 啶w肵āAVIuWFNgpIuWFNg쐬܂B<BR>
	 * 啶̏́Ajp.wda.gpss.util.FinderConditionInterpreter#interpret(Finder, String, String)
	 * B<BR>
	 * <BR>
	 * L[ɂ́A[U[Ap[^͌ŗLwł܂B<BR>
	 * [U[猟ꍇ́AL["username"ƂȂ܂B<BR>
	 * p[^猟ꍇ́Ap[^̓"p."t̂L[ƂȂ܂B<BR>
	 * lɁAŗL猟ꍇ̌L[́AŗL̓"a."tĂB<BR>
	 * j<BR>
	 * (p.room != "osyaberi" & (username == "amoi" | username == "kon")) & a.sleep != null<BR>
	 * 
	 * @param condition 
	 * @return VNCAg\PbgIuWFNg
	 * @throws jp.wda.gpss.util.FinderCreatingException 񂪕s̏ꍇ
	 * @see jp.wda.gpss.util.FinderConditionInterpreter#interpret(Finder, String, String)
	 */
	public static Finder getFinder(String condition) throws FinderCreatingException{
		return FinderConditionInterpreter.interpret(new SocketProcessorFinder(), "&", condition);
	}
}

==> gpss-1.02-src.zip: jp/wda/gpss/util/SocketProcessorFinder.java <==
package jp.wda.gpss.util;

/**
 * NCAg\Pbg NX
 *
 * @version	1.02		2003/09/09
 * @since		1.00003	2003/05/01
 * @author	amoi
 */
public class SocketProcessorFinder extends Finder {
	// RXgN^ ///////////////////////////////////////////////////////////////////
	//                                                                    Constructors //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 *	ftHg̐ݒpăIuWFNg\z܂B<BR>
	 */
	public SocketProcessorFinder(){ super(); }

	// I[@[Ch /////////////////////////////////////////////////////////////////
	//                                                               Over Ride Methods //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 * FinderNXɕKvȃ\bhB<BR>
	 * SocketProcessorFinderNXł͓ɉsȂ܂B<BR>
	 * 
	 * @param elem getlist / get\bhŏ𖞂ƊmFꂽIuWFNg
	 * @return getlist / get\bhŎۂɎgpl
	 * @see jp.wda.gpss.util.Finder#getReturnValue(Object)
	 */
	public Object getReturnValue(Object elem){
		return elem;
	}

	/* ***********************************************************************>> */;
	/**
	 * setNextCondition\bhɕKvȃ\bhB<BR>
	 * VSocketProcessorFinderIuWFNg𐶐܂B<BR>
	 * 
	 * @see jp.wda.gpss.util.Finder#createNewFinder()
	 * @see jp.wda.gpss.util.Finder#setNextCondition(Finder, Condition)
	 */
	protected Finder createNewFinder(){ return new SocketProcessorFinder(); }

	/* ***********************************************************************>> */;
	/**
	 * setNextCondition\bhɕKvȃ\bhB<BR>
	 * ̍ӒlƉEӒlw肵āAVFinderElement̃IuWFNgɒǉ܂B<BR>
	 * Ӓl̓2"p."̏ꍇ́Ap[^lpIuWFNgA<BR>
	 * "a."̏ꍇ̓NCAgŗLlpIuWFNgA<BR>
	 * ̏C傪tĂȂꍇA
	 * Ӓl"username"̏ꍇ̓[U[pIuWFNgA<BR>
	 * Ӓl"id"̏ꍇ̓[U[IDpIuWFNgÃIuWFNgɒǉ܂B<BR>
	 * 
	 * @see jp.wda.gpss.util.Finder#setNextFinder(boolean, boolean, String, String)
	 * @see jp.wda.gpss.util.Finder#setNextCondition(Finder, Condition)
	 */
	protected void setNextFinder(boolean con, boolean not, String column, String value){
		if(column == null || column.length() < 3){ return; }
//		if(value == null  || value.length() == 0){ return; }
		
		if(column.charAt(1) == '.'){
			if(column.charAt(0) == 'p'){
				addFinder(con, new SocketProcessorFinderByParameter(not, column.substring(2), value));
			}else if(column.charAt(0) == 'a'){
				addFinder(con, new SocketProcessorFinderByAttribute(not, column.substring(2), value));
			}
		}else if(column.equalsIgnoreCase("username")){
			addFinder(con, new SocketProcessorFinderByUsername(not, value));
		}else if(column.equalsIgnoreCase("id")){
			addFinder(con, new SocketProcessorFinderByID(not, value));
		}
	}

	// NX\bh ///////////////////////////////////////////////////////////////////
	//                                                                   Class Methods //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 * w肵āAVIuWFNgpIuWFNg쐬܂B<BR>
	 * v́A"=="Aے"!="gpĂB<BR>
	 * ̐ڑɂ́AANDڑ̏ꍇ'&'AORڑ̏ꍇ́A'|'gpł܂B<BR>
	 * ܂A"()"gpď̃O[vo܂B<BR>
	 * <BR>
	 * ̍Ӓlɂ́A[U[͏p[^AŗLwł܂B<BR>
	 * [U[ꍇ́AӒl"username"ƂȂ܂B<BR>
	 * ܂A[U[IDꍇ́AӒl"id"ƂȂ܂B<BR>
	 * p[^猟ꍇ́Ap[^̓"p."tĂB<BR>
	 * ŗL猟ꍇ́AŗL̓"a."tĂB<BR>
	 * j<BR>
	 * (p.room != osyaberi & (username == amoi | username == kon)) & a.sleep != sleep<BR>
	 * 
	 * @param condition 
	 * @deprecated
	 */
	public static SocketProcessorFinder create(String condition){
		SocketProcessorFinder ret = new SocketProcessorFinder();
		ret.setCondition(condition);
		return ret;
	}

	/* ***********************************************************************>> */;
	/**
	 * 啶w肵āAVIuWFNgpIuWFNg쐬܂B<BR>
	 * 啶̏́Ajp.wda.gpss.util.FinderConditionInterpreter#interpret(Finder, String, String)
	 * B<BR>
	 * <BR>
	 * L[ɂ́A[U[Ap[^͌ŗLwł܂B<BR>
	 * [U[猟ꍇ́AL["username"ƂȂ܂B<BR>
	 * ܂A[U[IDꍇ́AӒl"id"ƂȂ܂B<BR>
	 * p[^猟ꍇ́Ap[^̓"p."t̂L[ƂȂ܂B<BR>
	 * lɁAŗL猟ꍇ̌L[́AŗL̓"a."tĂB<BR>
	 * j<BR>
	 * (p.room != "osyaberi" & (username == "amoi" | username == "kon")) & a.sleep != null<BR>
	 * 
	 * @param condition 
	 * @return VNCAg\PbgIuWFNg
	 * @throws jp.wda.gpss.util.FinderCreatingException 񂪕s̏ꍇ
	 * @see jp.wda.gpss.util.FinderConditionInterpreter#interpret(Finder, String, String)
	 */
	public static Finder getFinder(String condition) throws FinderCreatingException{
		return FinderConditionInterpreter.interpret(new SocketProcessorFinder(), "&", condition);
	}
}
